@@ -20,7 +20,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -85,6 +85,8 @@ gcpReactionStep::gcpReactionStep (gcpReaction *reaction, map<double, Object*>& C
 
 gcpReactionStep::~gcpReactionStep ()
 {
+	if (IsLocked ())
+		return;
 	set<gcpReactionArrow *>::iterator i, end = m_Arrows.end();
 	for (i = m_Arrows.begin (); i != end; i++)
 		(*i)->RemoveStep (this);
@@ -108,7 +110,7 @@ gcpReactionStep::~gcpReactionStep ()
 			continue;
 		}
 		Reactant = reinterpret_cast<gcpReactant *> (Child);
-		Child = Reactant->GetStoechChild ();
+		Child = Reactant->GetStoichChild ();
 		if (Child)
 			pDoc->Remove (Child);
 		Child = Reactant->GetChild ();
@@ -132,7 +134,7 @@ xmlNodePtr gcpReactionStep::Save (xmlDocPtr xml)
 	xmlNodePtr child;
 	while (obj) {
 		if ((*i).second->GetType () != ReactionOperatorType) {
-			if (child = (*i).second->Save (xml)) xmlAddChild (node, child);
+			if ((child = (*i).second->Save (xml))) xmlAddChild (node, child);
 			else return NULL;
 		}
 		obj = GetNextChild (i);
@@ -192,7 +194,7 @@ bool gcpReactionStep::Load (xmlNodePtr node)
 double gcpReactionStep::GetYAlign ()
 {
 	map<string, Object*>::iterator i;
-	Object *child = GetFirstChild (i);
+	GetFirstChild (i);
 	return ((*i).second)? (*i).second->GetYAlign (): 0.;
 }
 
