@@ -215,7 +215,7 @@ bool gcpText::SaveNode(xmlDocPtr xml, xmlNodePtr node, GtkTextIter *iter, GtkTex
 			*iter = *end;
 		}
 		char *rn, *text = gtk_text_buffer_get_text(m_buf, &start, iter, true);
-		while (rn = strchr(text, '\n'))
+		while ((rn = strchr(text, '\n')))
 		{
 			xmlNodeAddContentLen(node, (xmlChar*)text, rn - text);
 			text = rn + 1;
@@ -474,7 +474,6 @@ bool gcpText::OnChanged (GtkTextBuffer *textbuffer)
 		return true;
 	}
 	while (bNotEnd) {
-		gtk_text_iter_backward_line (&iter);
 		gnome_canvas_rich_text_ext_get_iter_location (text, &iter, &rect);
 		if (left > rect.x)
 			left = rect.x;
