@@ -15,10 +15,10 @@
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
  * Lesser General Public License for more details.
  *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the 
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA  02111-1307, USA.
+ * You should have received a copy of the GNU Lesser General Public License
+ * along with this program; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
+ * USA
  */
 
 #include "gchempaint-config.h"
@@ -53,6 +53,7 @@ void pango_layout_print (GnomePrintContext *gpc, PangoLayout* pl)
 		pa->end_index = l;
 		pango_attr_list_insert (pal, pa);
 		pango_layout_set_attributes (layout, pal);
+		pango_attr_list_unref (pal);
 	}
 	gnome_print_gsave (gpc);
 	gnome_print_scale (gpc, zoom, -zoom); /* not so good. Why is zoom necessary to get the same size ? Have a look at resolution */
