@@ -44,6 +44,8 @@ private:
 	double m_dDist, m_dDistMax, m_dAngle;
 	int m_Charge;
 	unsigned char m_Pos, m_DefaultPos;
+	bool m_bDragged;
+	double m_ChargeWidth, m_ChargeTWidth, m_ChargeHeight;
 };
 
 #endif	//GCHEMPAINT_CHARGE_TOOL_H
